@@ -1,5 +1,8 @@
+// $Id: VolVolume.hpp 375 2013-11-22 15:46:16Z tkr $
 // Copyright (C) 2000, International Business Machines
 // Corporation and others.  All Rights Reserved.
+// This code is licensed under the terms of the Eclipse Public License (EPL).
+
 #ifndef __VOLUME_HPP__
 #define __VOLUME_HPP__
 
@@ -7,6 +10,8 @@
 #include <algorithm>
 #include <cstdio>
 #include <cmath>
+#include <cstring>
+#include <cstdlib>
 
 #ifndef VOL_DEBUG
 // When VOL_DEBUG is 1, we check vector indices
@@ -159,8 +164,8 @@ public:
    VOL_dvector(const VOL_dvector& x) : v(0), sz(0) {
       sz = x.sz;
       if (sz > 0) {
-	 v = new double[sz];
-	 std::copy(x.v, x.v + sz, v);
+        v = new double[sz];
+        std::memcpy(v, x.v, sz * sizeof(double));
       }
    }
    /** The destructor deletes the data array. */
@@ -253,7 +258,7 @@ public:
       sz = x.sz;
       if (sz > 0) {
 	 v = new int[sz];
-	 std::copy(x.v, x.v + sz, v);
+	 std::memcpy(v, x.v, sz * sizeof(int));
       }
    }
    /** The destructor deletes the data array. */
